| Home | Libraries | People | FAQ | More

### is_member_function_pointer

    template <class T>
    struct is_member_function_pointer : public true_type-or-false_type {};

Inherits: If T is a (possibly cv-qualified) pointer to a member function then inherits from true_type, otherwise inherits from false_type.

C++ Standard Reference: 3.9.2 and 8.3.3.

Header: `#include <boost/type_traits/is_member_function_pointer.hpp>` or `#include <boost/type_traits.hpp>`

Examples:

> `is_member_function_pointer<int (MyClass::*)(void)>` inherits from `true_type`.

> `is_member_function_pointer<int (MyClass::*)(char)>::type` is the type `true_type`.

> `is_member_function_pointer<int (MyClass::*)(void)const>::value` is an integral constant expression that evaluates to true.

> `is_member_function_pointer<int (MyClass::*)>::value` is an integral constant expression that evaluates to false: the argument in this case is a pointer to a data member and not a member function, see is_member_object_pointer and is_member_pointer

> `is_member_function_pointer<T>::value_type` is the type `bool`.